@@ -1,6 +1,4 @@
 /*
- * usr/kinit/do_mounts_md.c
- *
  * Handle autoconfiguration of md devices.  This is ugly, partially since
  * it still relies on a sizable kernel component.
  *
@@ -16,12 +14,12 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <alloca.h>
 #include <inttypes.h>
 #include <sys/sysmacros.h>
 #include <sys/md.h>
 #include <linux/major.h>
 
+#include "kinit.h"
 #include "do_mounts.h"
 
 #define  LEVEL_NONE              (-1000000)
@@ -144,7 +142,7 @@ static int mdp_major(void)
  */
 static int md_setup(char *str)
 {
-	int minor, level, factor, fault, partitioned = 0;
+	int minor_num, level, factor, fault, partitioned = 0;
 	char *pername = "";
 	char *str1;
 	int ent;
@@ -153,28 +151,28 @@ static int md_setup(char *str)
 		partitioned = 1;
 		str++;
 	}
-	if (get_option(&str, &minor) != 2) {	/* MD Number */
+	if (get_option(&str, &minor_num) != 2) {	/* MD Number */
 		fprintf(stderr, "md: Too few arguments supplied to md=.\n");
 		return 0;
 	}
 	str1 = str;
-	if (minor >= MAX_MD_DEVS) {
+	if (minor_num >= MAX_MD_DEVS) {
 		fprintf(stderr, "md: md=%d, Minor device number too high.\n",
-			minor);
+			minor_num);
 		return 0;
 	}
 	for (ent = 0; ent < md_setup_ents; ent++)
-		if (md_setup_args[ent].minor == minor &&
+		if (md_setup_args[ent].minor == minor_num &&
 		    md_setup_args[ent].partitioned == partitioned) {
 			fprintf(stderr,
 				"md: md=%s%d, Specified more than once. "
 				"Replacing previous definition.\n",
-				partitioned ? "d" : "", minor);
+				partitioned ? "d" : "", minor_num);
 			break;
 		}
 	if (ent >= MAX_MD_DEVS) {
 		fprintf(stderr, "md: md=%s%d - too many md initialisations\n",
-			partitioned ? "d" : "", minor);
+			partitioned ? "d" : "", minor_num);
 		return 0;
 	}
 	if (ent >= md_setup_ents)
@@ -206,10 +204,10 @@ static int md_setup(char *str)
 	}
 
 	fprintf(stderr, "md: Will configure md%s%d (%s) from %s, below.\n",
-		partitioned?"_d":"", minor, pername, str);
+		partitioned?"_d":"", minor_num, pername, str);
 	md_setup_args[ent].device_names = str;
 	md_setup_args[ent].partitioned = partitioned;
-	md_setup_args[ent].minor = minor;
+	md_setup_args[ent].minor = minor_num;
 
 	return 1;
 }
@@ -228,6 +226,7 @@ static void md_setup_drive(void)
 		char *devname;
 		mdu_disk_info_t dinfo;
 		char name[16];
+		struct stat st_chk;
 
 		dev_minor = md_setup_args[ent].minor;
 		partitioned = md_setup_args[ent].partitioned;
@@ -236,6 +235,9 @@ static void md_setup_drive(void)
 		snprintf(name, sizeof name,
 			 "/dev/md%s%d", partitioned ? "_d" : "", dev_minor);
 
+		if (stat(name, &st_chk) == 0)
+			continue;
+
 		if (partitioned)
 			dev = makedev(mdp_major(), dev_minor << MdpMinorShift);
 		else
