@@ -49,8 +49,8 @@ int bootp_send_request(struct netdev *dev)
 	bootp.secs	= htons(time(NULL) - dev->open_time);
 	memcpy(bootp.chaddr, dev->hwaddr, 16);
 
-	DEBUG(("-> bootp xid 0x%08x secs 0x%08x ",
-	       bootp.xid, ntohs(bootp.secs)));
+	dprintf("-> bootp xid 0x%08x secs 0x%08x ",
+		bootp.xid, ntohs(bootp.secs));
 
 	return packet_send(dev, iov, 2);
 }
@@ -135,7 +135,7 @@ int bootp_parse(struct netdev *dev, struct bootp_hdr *hdr,
 				memcpy(&dev->nisdomainname, ext, len);
 				dev->nisdomainname[len] = '\0';
 				break;
-			case 54: 	/* server identifier */
+			case 54:	/* server identifier */
 				if (len == 4 && !dev->ip_server)
 					memcpy(&dev->ip_server, ext, 4);
 				break;
@@ -153,6 +153,10 @@ int bootp_parse(struct netdev *dev, struct bootp_hdr *hdr,
 
 /*
  * Receive a bootp reply and parse packet
+ * Returns:
+ *-1 = Error in packet_recv, try again later
+ * 0 = Unexpected packet, discarded
+ * 1 = Correctly received and parsed packet
  */
 int bootp_recv_reply(struct netdev *dev)
 {
