@@ -11,7 +11,7 @@
 
 int do_mounts(int argc, char *argv[]);
 int mount_nfs_root(int argc, char *argv[], int flags);
-int ramdisk_load(int argc, char *argv[], dev_t root_dev);
+int ramdisk_load(int argc, char *argv[]);
 void md_run(int argc, char *argv[]);
 const char *bdevname(dev_t dev);
 
@@ -48,16 +48,14 @@ ssize_t freadfile(FILE *f, char **pptr);
         (void) (&_x == &_y);            \
         _x > _y ? _x : _y; })
 
-#define INI_DEBUG
 
-#undef DEBUG
-#ifdef INI_DEBUG
-#define DEBUG(x) printf x
+#ifdef DEBUG
+# define dprintf printf
 #else
-#define DEBUG(x) do { } while (0)
+# define dprintf(...) ((void)0)
 #endif
 
-#ifdef INI_DEBUG
+#ifdef DEBUG
 void dump_args(int argc, char *argv[]);
 #else
 static inline void dump_args(int argc, char *argv[])
